local npc_cell = npc_class:new()
RegisterNPC("Cell", npc_cell)

npc_cell.team = -1
npc_cell.health = 100
npc_cell.attackdist = 280
npc_cell.movementdelay = 0
npc_cell.movementspeed = 3
npc_cell.sprite = "gfx/starkkz/models/npcs/cell.png"
npc_cell.spritescalex = 1
npc_cell.spritescaley = 1
npc_cell.viewdist = 280

function npc_cell:UpdateShot()
	if self.var.shotSprite > 0 then
		imagepos(self.var.shotSprite, self:x(), self:y(), self:rot())
	end
end

function npc_cell:RemoveShot()
	if self.var.shotSprite > 0 then
		freeimage(self.var.shotSprite)
		self.var.shotSprite = 0
	end
end

function npc_cell:init()
	-- Initial values
	self.var = {}
	self.timer = {}

	self.var.StepTimer = 0
	self.var.AttackTimer = 0
	self.var.weaponpath = "gfx/weapons/scar.png"
	self.var.shotpath = "gfx/starkkz/models/NPCshot.bmp"
	self.var.shotSprite = 0

	self.var.weaponSprite = image(self.var.weaponpath,0,1,3)
	imagepos(self.var.weaponSprite, self:x(), self:y(), self:rot())
end

function npc_cell:setpos(x,y,rot)
	if self:exists() then
		local comp_x = x or self:x()
		local comp_y = y or self:y()
		local comp_rot = rot or self:rot()

		if comp_x ~= self:x() or comp_y ~= self:y() or comp_rot ~= self:rot() then
			imagepos(self.id, comp_x, comp_y, comp_rot)
			if self.var.weaponSprite then
				imagepos(self.var.weaponSprite, comp_x, comp_y, comp_rot)
			end
		end
	end
end

function npc_cell:UpdateSprite()
	-- Update bullet
	self:UpdateShot()
end

function npc_cell:onDie()
	Sound3("player/die"..math.random(1,3)..".wav", self:x(), self:y(), self.viewdist)

	-- Remove shoot image
	freeimage(self.var.weaponSprite)

	-- Remove from the NPC List
	self:freeslot()
end

function npc_cell:onHit(attacker,wpn,dmg,isNPC)
	self.health = self.health - dmg
	if self.health <= 0 then
		-- Do self death
		self:onDie()
	else
		-- Pain sound
		Sound3("player/hit"..math.random(1,3)..".wav", self:x(), self:y(), self.viewdist)
	end
end

function npc_cell:onAttack(tid,isNPC)
	-- Function called while NPC is in an attack range

	if isNPC then
		self:setpos(self:x(), self:y(), math.deg(AngleBetween(self:x(), self:y(), NPC_Tab[tid]:x(), NPC_Tab[tid]:y())))
	else
		self:setpos(self:x(), self:y(), math.deg(AngleBetween(self:x(), self:y(), player(tid,"x"), player(tid,"y"))))
	end

	if Millisecs() - self.var.AttackTimer then
		-- Sound fx and timer
		Sound3("starkkz/weapons/scar-l_fire.wav", self:x(), self:y(), 400)
		self.var.AttackTimer = Millisecs() + 100

		-- Damage
		if isNPC then
			NPC_Tab[tid]:onHit(self.id, 0, 8 + math.random(-1,1),true)
		else
			local h, a = CalcDamage(player(tid,"health"),player(tid,"armor"),8 + math.random(-1,1))
			if h > 0 then
				parse("sethealth "..tid.." "..h)
				parse("setarmor "..tid.." "..a)
			else
				parse([[customkill 0 "Cell's SCAR" ]]..tid)
			end
		end

		-- Fire sprite
		self.var.shotSprite = image(self.var.shotpath,0,1,3)
		imagepos(self.var.shotSprite, self:x(), self:y(), self:rot())

		AddTimer(50,self:RemoveShot())
	end

	self:UpdateSprite()
end

--function npc_cell:onUseEvent(id,range)
	-- Id of player who did the action, And range into him and the NPC
	-- Do nothing, is not a hostage
--end

function npc_cell:onMove()
	if Millisecs() - self.var.StepTimer >= 0 then
		local tilex, tiley = self:tilex(), self:tiley()

		self.var.StepTimer = Millisecs() + 300
		if TileDirt(tilex,tiley) then
			Sound3("player/pl_dirt"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileSnow(tilex,tiley) then
			Sound3("player/pl_snow"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileStep(tilex,tiley) then
			Sound3("player/pl_step"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileTile(tilex,tiley) then
			Sound3("player/pl_tile"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileWater(tilex,tiley) then
			Sound3("player/pl_wade"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileMetal(tilex,tiley) then
			Sound3("player/pl_metal"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileWood(tilex,tiley) then
			Sound3("player/pl_wood"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		end
	end
end

function npc_cell:checkVisual(x,y)
	return math.abs(self:x() - x) <= 320 and math.abs(self:y() - y) <= 240 and self:dist(x, y) < self.attackdist and self:attackable(x, y)
end
