local npc_strider = npc_class:new()
RegisterNPC("strider", npc_strider)

npc_strider.team = 0
npc_strider.health = 2000
npc_strider.attackdelay = 200
npc_strider.attackdist = 250
npc_strider.movementdelay = 1000
npc_strider.movementspeed = 32
npc_strider.movementmax = 100
npc_strider.sprite = "gfx/starkkz/models/npcs/strider/strider_legs.bmp"
npc_strider.spritemode = 3
npc_strider.hitzonemode = 101
npc_strider.viewdist = 500

npc_strider.HitSound = {
	{Dir = "starkkz/npc/strider/striderx_pain1.ogg", Duration = 1498},
	{Dir = "starkkz/npc/strider/striderx_pain2.ogg", Duration = 663},
	{Dir = "starkkz/npc/strider/striderx_pain3.ogg", Duration = 925},
	{Dir = "starkkz/npc/strider/striderx_pain4.ogg", Duration = 1117}
}

function npc_strider:init()
	self.var = {}
	self.timer = {}

	self.HitSoundID = 0

	self.TurretSprite = image("gfx/starkkz/models/npcs/strider/strider_tu.bmp", 0, 0, 3)

	self.LastHit = 0
	self.ShotCount = 0
	self.ShotDelay = 0

	self.AimRotTarget = self:rot()
	self.AimLast = 0
	imagepos(self.TurretSprite, self:x(), self:y(), self:rot())
end

function npc_strider:tweenUpdateSprite(t,x,y)
	local _r = self.var.lastrot or 0
	tween_move(self.TurretSprite, t, x, y)
end

function npc_strider:aim(x,y)
	local rot = math.deg(self:angle(x,y))
	if self.AimRotTarget ~= rot and Millisecs() - self.AimLast >= self.attackdelay then
		self.AimRotTarget = rot
		self.AimLast = Millisecs()
		tween_rotate(self.TurretSprite, self.attackdelay, rot)
	end
end

function npc_strider:onDie()
	self:sound3("starkkz/npc/strider/striderx_die.ogg", 400)
	if self.TurretSprite and object(self.TurretSprite, "exists") then
		freeimage(self.TurretSprite)
	end
	self:freeslot()

	if self.block_img and object(self.block_img, "exists") then
		freeimage(self.block_img)
		self.block_img = nil
	end
end

function npc_strider:onHit(attacker, wpn, Damage, isNPC)
	self.health = self.health - Damage
	if self.health <= 0 then
		self:onDie()
	elseif Millisecs() >= self.LastHit + self.HitSound[self.var.HitSoundID].Duration then
		self.LastHit = Millisecs()
		self.HitSoundID = ((self.HitSoundID + math.random(1, 4) - 1) % #self.HitSound) + 1
		self:sound3(self.HitSound[self.HitSoundID].Dir, 380)
	end
end

function npc_strider:onMove(x,y,r)
	self:sound3("starkkz/npc/strider/strider_step"..math.random(1,6)..".ogg", 400)
	if self.lastTarget == 0 then self:aim(x, y) end

	if not self.var.lastrot then
		self.var.lastrot = 15
	else
		self.var.lastrot = -self.var.lastrot
	end
	return 0, r + self.var.lastrot
end

function npc_strider:Always()
	if self.fire_executed then
		if Millisecs() - self.fire_start >= 1229 then
			if self.block_img and object(self.block_img, "exists") then
				freeimage(self.block_img)
				self.block_img = nil
			end

			local targets = self:ClosestTargets(self.fire_id, 96, self.fire_npc)
			parse("flashposition "..self.fire_x.." "..self.fire_y.." 50")
			self.fire_executed = false

			for _, t in pairs(targets) do
				local _id = t[1]
				local _isNPC = t[2]
				if _isNPC and _id ~= self.id then
					NPC_Tab[_id]:onHit(_id, 0, 1000, true)
				end
			end

			parse("explosion "..self.fire_x.." "..self.fire_y.." 128 1000")
		end
	end
end

function npc_strider:onAttack(id,isNPC)
	if Millisecs() - self.ShotDelay >= 2000 then
		if self.targetAttackable then
			local targets = self:ClosestTargets(id, 64, isNPC)

			if #targets >= 3 then
				if not self.fire_executed then
					self:sound3("starkkz/npc/strider/charging.ogg", 380)
					self.last_attack = Millisecs() + 3000
					self.last_move = Millisecs() + 1229
					self.fire_executed = true
					self.fire_start = Millisecs()
					self.fire_npc = isNPC
					self.fire_id = id
					self.fire_x = self.targetx
					self.fire_y = self.targety

					self.block_img = image("gfx/sprites/block.bmp", 0, 0, 1)
					imagescale(self.block_img, 1/32, self:dist(self.targetx, self.targety)/32)
					imagepos(self.block_img, (self.targetx + self:x())/2, (self.targety + self:y())/2, math.deg(self:angle(self.targetx, self.targety)))
				end
			else
				if isNPC then
					NPC_Tab[id]:onHit(self.id, 0, math.random(10,14) , true)
				else
					local h, a = CalcDamage(player(id,"health"), player(id,"armor"), math.random(8,12))
					if h > 0 then
						parse("sethealth "..id.." "..h)
						parse("setarmor "..id.." "..a)
					else
						parse('customkill 0 "Strider" '..id)
					end
				end

				local img = image("gfx/starkkz/models/npcs/strider/strider_shot.bmp", 0, 0, 1)
				imagepos(img, self:x(), self:y(), object(self.TurretSprite, "rot") or self:rot())
				tween_alpha(img, 200, 0)
				timer(500, "freeimage", img)

				self:sound3("starkkz/npc/strider/strider_minigun"..math.random(1,2)..".ogg", 380)

				self.ShotCount = self.ShotCount + 1
				if self.ShotCount >= 10 then
					self.ShotDelay = Millisecs()
					self.ShotCount = 0
				end
			end
		end
	end
end
