local SpitList = {}
function UpdateBullsquidSpits()
	for k, v in pairs(SpitList) do
		-- Calculate Information
		local Ang = math.rad(v.rot)
		local rot = v.rot
		x = v.x + math.sin(Ang) * 20
		y = v.y - math.cos(Ang) * 20
		v.distance = v.distance + 20

		-- Check if the fly can pass it
		if tile(math.floor(x/32), math.floor(y/32), "wall") or v.distance > 250 then
			Sound3("starkkz/npc/bullchicken/bc_acid"..math.random(1, 2)..".wav", x, y, 280)
			Sound3("starkkz/npc/bullchicken/bc_spithit"..math.random(1, 3)..".wav", x, y, 280)
			freeimage(v.img)
			SpitList[k] = nil
		end

		-- Update fly information
		v.x = x
		v.y = y
		v.rot = rot
		tween_move(v.img, 80, x, y, rot)

		for n, i in pairs(NPC_Tab) do
			if SpitList[k] and DistBetween(i:x(), i:y(), v.x, v.y) < 20 then
				Sound3("starkkz/npc/bullchicken/bc_acid"..math.random(1, 2)..".wav", v.x, v.y, 280)
				Sound3("starkkz/npc/bullchicken/bc_spithit"..math.random(1, 3)..".wav", v.x, v.y, 280)
				freeimage(v.img)
				SpitList[k] = nil
				i:onHit(k, "Bullsquid Spit", 8 + math.random(-2,2), true)
				break
			end
		end

		if SpitList[k] then
			for _, id in pairs(player(0,"table")) do
				if DistBetween(player(id,"x"), player(id,"y"), v.x, v.y) < 20 then
					Sound3("starkkz/npc/bullchicken/bc_acid"..math.random(1, 2)..".wav", v.x, v.y, 280)
					Sound3("starkkz/npc/bullchicken/bc_spithit"..math.random(1, 3)..".wav", v.x, v.y, 280)
					freeimage(v.img)
					SpitList[k] = nil
					local h, a = CalcDamage(player(id,"health"), player(id,"armor"), 8 + math.random(-2,2))
					if h > 0 then
						parse("sethealth "..id.." "..h)
						parse("setarmor "..id.." "..a)
					else
						parse('customkill 0 "Alien Grunt Hornet" '..id)
					end
					break
				end
			end
		end
	end
end
timer(80, "UpdateBullsquidSpits", "",0)

local npc_bullsquid = npc_class:new()
RegisterNPC("Bullsquid", npc_bullsquid)

npc_bullsquid.team = 0
npc_bullsquid.health = 120
npc_bullsquid.attackdelay = 1500
npc_bullsquid.attackdist = 250
npc_bullsquid.attackmindist = 32

npc_bullsquid.meleeattackdist = 48
npc_bullsquid.meleeattackdelay = 760

npc_bullsquid.movementdelay = 80
npc_bullsquid.movementspeed = 10
npc_bullsquid.movementmax = 8
npc_bullsquid.sprite = "gfx/models/bullsquid/bullsquid.png"
npc_bullsquid.spritescalex = 1
npc_bullsquid.spritescaley = 1
npc_bullsquid.spritemode = 1
npc_bullsquid.hitzonemode = 3
npc_bullsquid.viewdist = 380
npc_bullsquid.width = 36
npc_bullsquid.height = 36

npc_bullsquid.HitSound = {
	{Dir = "starkkz/npc/bullchicken/bc_pain1.wav", Duration = 683},
	{Dir = "starkkz/npc/bullchicken/bc_pain2.wav", Duration = 536},
	{Dir = "starkkz/npc/bullchicken/bc_pain3.wav", Duration = 940},
}

function npc_bullsquid:init()
	self.timer = {}
	self.StepTimer = 0
end

function npc_bullsquid:onDie()
	self:sound3("starkkz/npc/bullchicken/bc_die"..math.random(1, 3)..".wav", 300)
	self:freeslot()
end

function npc_bullsquid:onHit(Attacker, Weapon, Damage, isNPC)
	self.health = self.health - Damage
	if self.health <= 0 then
		self:onDie()
	elseif not self.HitSoundID or Millisecs() >= self.LastHit + self.HitSound[self.HitSoundID].Duration then
		self.LastHit = Millisecs()
		self.HitSoundID = math.random(1, #self.HitSound)
		self:sound3(self.HitSound[self.HitSoundID].Dir, 300)
	end
end

function npc_bullsquid:moveAvail()
	if self.LastMelee then
		if Millisecs() - self.LastMelee < self.meleeattackdelay then
			return false
		end
	end
	if self.LastSpit then
		if Millisecs() - self.LastSpit < self.attackdelay then
			return false
		end
	end
	return Millisecs() - self.last_move >= self.movementdelay and Millisecs() - self.last_move >= self.movementsleep
end

function npc_bullsquid:onMove(x, y)
	if Millisecs() - self.StepTimer >= 0 then
		local tilex, tiley = self:tilex(), self:tiley()

		self.StepTimer = Millisecs() + 300
		if TileDirt(tilex,tiley) then
			Sound3("player/pl_dirt"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileSnow(tilex,tiley) then
			Sound3("player/pl_snow"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileStep(tilex,tiley) then
			Sound3("player/pl_step"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileTile(tilex,tiley) then
			Sound3("player/pl_tile"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileWater(tilex,tiley) then
			Sound3("player/pl_wade"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileMetal(tilex,tiley) then
			Sound3("player/pl_metal"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileWood(tilex,tiley) then
			Sound3("player/pl_wood"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		end
	end
end

function npc_bullsquid:onAttack(id,isNPC)
	if self:distObject(id, isNPC) < self.meleeattackdist then
		if isNPC then
			NPC_Tab[id]:onHit(self.id, 78, 20, true)
		else
			local h, a = CalcDamage(player(id,"health"), player(id,"armor"), math.random(17, 19))
			if h > 0 then
				parse("sethealth "..id.." "..h)
				parse("setarmor "..id.." "..a)
			else
				parse('customkill 0 "Bullsquid" '..id)
			end
		end
		self:sound3("starkkz/npc/bullchicken/bc_bite"..math.random(1, 3)..".wav", 300)
		self.LastMelee = Millisecs()
	else
		local rot = self:rot()
		local rad = math.rad(rot)
		self:spawnSpit(self:x() + math.sin(rad) * 32, self:y() - math.cos(rad) * 32, rot)
		self.LastSpit = Millisecs()
	end
end

function npc_bullsquid:spawnSpit(x, y, rot)
	local Spit = {
		x = x,
		y = y,
		rot = rot,
		distance = 0,
		img = image("gfx/weapons/snowball.bmp<m>", 0, 1, 3)
	}
	imagecolor(Spit.img, 50, 200, 50)
	imagepos(Spit.img, x, y, rot)
	table.insert(SpitList, Spit)
end
