local OvalEffect = {}
function UpdateOvals()
	for i, Effect in pairs(OvalEffect) do
		Effect.scale = OvalEffect[i].scale + (OvalEffect[i].speed/100)
		imagepos(Effect.img, Effect.x, Effect.y,0)
		imagescale(Effect.img, Effect.scale, Effect.scale)
		if Effect.scale >= Effect.maxscale then
			freeimage(Effect.img)
			OvalEffect[i] = nil
		end
	end
end
timer(20, "UpdateOvals", "",0)

function DrawOval(maxscale,speed,x,y)
	-- This is an extra function used for the NPC Atack Effect
	local Sprite = "gfx/sprites/wave.bmp"
	local id = #OvalEffect + 1
	local Effect = {
		img = image(Sprite,0,1,0),
		scale = 1,
		maxscale = maxscale,
		x = x,
		y = y,
		speed = speed
	}
	imagepos(Effect.img, x, y, 0)
	imageblend(Effect.img, 1)
	OvalEffect[id] = Effect
end

local npc_houndeye = npc_class:new()
RegisterNPC("HoundEye", npc_houndeye)

npc_houndeye.team = 0
npc_houndeye.health = 100
npc_houndeye.attackdelay = 0
npc_houndeye.attackdist = 64
npc_houndeye.movementdelay = 150
npc_houndeye.movementspeed = 16
npc_houndeye.movementmax = 8
npc_houndeye.sprite = "gfx/HL2D/houndeye.bmp"
npc_houndeye.spritescalex = 0.3
npc_houndeye.spritescaley = 0.3
npc_houndeye.spritemode = 0
npc_houndeye.hitzonemode = 3
npc_houndeye.viewdist = 380
npc_houndeye.width = 16
npc_houndeye.height = 16

function npc_houndeye:init()
	self.var = {}
	self.timer = {}

	self.canDrawOval = false
	self.OvalTimer = 0
	self.SoundTimer = 0
end

function npc_houndeye:BlastAttackAvail()
	return self.canDrawOval == true and Millisecs() - self.OvalTimer >= 0
end

function npc_houndeye:Always()
	if self:BlastAttackAvail() then
		-- Oval Effect
		self.canDrawOval = false
		DrawOval(4, 9, self:x(),self:y())
		DrawOval(3, 5, self:x(),self:y())

		-- Select a random sound to play
		Sound3("starkkz/npc/houndeye/he_blast"..math.random(1,3)..".wav", self:x(), self:y(), 400)

		-- Also do the damage action
		local targets = self:ClosestTargets(64) -- 2 Tiles = 64 Pixels
		for k, v in pairs(targets) do
			-- Enemid id player / npc
			local n = v[1]
			local v = NPC_Tab[n]
			local isNPC = v[2]
			if isNPC then
				-- Give the local information to the victim NPC
				v:onHit(self.id, "HoundEye Blast", 20 + math.random(-5,5), false)
			else
				-- Calculate the damage
				local h, a = CalcDamage(player(n,"health"), player(n,"armor"), 20 + math.random(-5,5))
				if h > 0 then
					parse("sethealth "..n.." "..h)
					parse("setarmor "..n.." "..a)
				else
					parse('customkill 0 "HoundEye" '..n)
				end
			end
		end
	end
end

function npc_houndeye:onDie()
	-- Select a random sound to play
	Sound3("starkkz/npc/houndeye/he_die"..math.random(1,3)..".wav", self:x(),self:y(),300)

	-- And finally, remove him from the NPC List
	self:freeslot()
end

function npc_houndeye:onHit(attacker,wpn,dmg,isNPC)
	self.health = self.health - dmg
	if self.health <= 0 then
		-- Do self death
		return self:onDie()
	end
	Sound3("starkkz/npc/houndeye/he_pain"..math.random(1,5)..".wav",self:x(),self:y(),300)
end

function npc_houndeye:onAttack(id,isNPC)

	-- Create an array of sound informations
	local Sounds = {
		[1] = {dir = "starkkz/npc/houndeye/he_attack1.wav",timer = 2620},
		[2] = {dir = "starkkz/npc/houndeye/he_attack2.wav",timer = 1666},
		[3] = {dir = "starkkz/npc/houndeye/he_attack3.wav",timer = 3039},
	}

	-- Search a random sound in the array
	local RandomSound = Sounds[math.random(1,#Sounds)]

	-- Timers
	self.movementsleep = RandomSound.timer
	self.OvalTimer = Millisecs() + RandomSound.timer
	self.attackdelay = RandomSound.timer

	-- NPC effects
	Sound3(RandomSound.dir, self:x(), self:y(), 400)
	self.canDrawOval = true
end

function npc_houndeye:onMove(x,y,r)
	-- Check if we can play a new sound of movement
	if Millisecs() - self.SoundTimer >= 0 then
		-- Yes we can, make an array of sound informations
		local Sounds = {
			[1] = {dir = "starkkz/npc/houndeye/he_hunt1.wav",timer = 262},
			[2] = {dir = "starkkz/npc/houndeye/he_hunt2.wav",timer = 246},
			[3] = {dir = "starkkz/npc/houndeye/he_hunt3.wav",timer = 260},
			[4] = {dir = "starkkz/npc/houndeye/he_hunt4.wav",timer = 494},
		}
		local RandomSound = Sounds[math.random(1,#Sounds)]
		Sound3(RandomSound.dir, self:x(), self:y(), 380)
		self.SoundTimer = Millisecs() + RandomSound.timer
		self.movementsleep = Sounds.timer
	end
end
