local npc_zombie = npc_class:new()
RegisterNPC("zombie", npc_zombie)

npc_zombie.team = -1
npc_zombie.health = 200
npc_zombie.attackdist = 16
npc_zombie.attackdelay = 600
npc_zombie.movementdelay = 120
npc_zombie.movementspeed = 16
npc_zombie.movementmax = 16
npc_zombie.sprite = "gfx/starkkz/Zombie/zombie.bmp"

npc_zombie.HitSound = {
	{Dir = "starkkz/zombie/zombie_pain1.wav", Duration = 683},
	{Dir = "starkkz/zombie/zombie_pain2.wav", Duration = 536},
	{Dir = "starkkz/zombie/zombie_pain3.wav", Duration = 940},
	{Dir = "starkkz/zombie/zombie_pain4.wav", Duration = 608},
	{Dir = "starkkz/zombie/zombie_pain5.wav", Duration = 475},
}

function npc_zombie:init()
	self.var = {}
	self.timer = {}

	self.LastHit = 0
	self.StepTimer = 0
end

function npc_zombie:onDie()
	self:sound3("starkkz/zombie/die_"..math.random(1,5)..".ogg", 300)
	self:freeslot()
end

function npc_zombie:onHit(Attacker, Weapon, Damage, isNPC)
	self.health = self.health - Damage
	if self.health <= 0 then
		self:onDie()
	end

	if not self.HitSoundID or Millisecs() >= self.LastHit + self.HitSound[self.HitSoundID].Duration then
		self.LastHit = Millisecs()
		self.HitSoundID = math.random(1, #self.HitSound)
		self:sound3(self.HitSound[self.HitSoundID].Dir, 300)
	end
end

function npc_zombie:onMove(x,y)
	if Millisecs() - self.StepTimer >= 0 then
		local tilex, tiley = self:tilex(), self:tiley()

		self.StepTimer = Millisecs() + 300
		if TileDirt(tilex,tiley) then
			Sound3("player/pl_dirt"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileSnow(tilex,tiley) then
			Sound3("player/pl_snow"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileStep(tilex,tiley) then
			Sound3("player/pl_step"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileTile(tilex,tiley) then
			Sound3("player/pl_tile"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileWater(tilex,tiley) then
			Sound3("player/pl_wade"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileMetal(tilex,tiley) then
			Sound3("player/pl_metal"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		elseif TileWood(tilex,tiley) then
			Sound3("player/pl_wood"..math.random(1,4)..".wav", self:x(), self:y(), 300)
		end
	end
end

function npc_zombie:onAttack(id,isNPC)
	if isNPC then
		NPC_Tab[id]:onHit(self.id, 78, 20, true)
	else
		local h, a = CalcDamage(player(id,"health"), player(id,"armor"), 20)
		if h > 0 then
			parse("sethealth "..id.." "..h)
			parse("setarmor "..id.." "..a)
		else
			parse('customkill 0 "Zombie" '..id)
		end
	end
	self:sound3("player/zm_hit.wav", 300)
end

function npc_zombie:checkVisual(x,y)
	return math.abs(self:x() - x) <= 320 and math.abs(self:y() - y) <= 240
end
